unit {<<UnitName>>};

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, AaWiz;

type

  {<<ClassName>>} = class(TAAQuestion)
  private
    FPrompt: string;
    FPromptLabel: TLabel;
    F{<<Link>>}: TAAQuestion;
  protected
    procedure Notification(comp: TComponent; op: TOperation);override;
  public
    constructor Create(aowner: TComponent);override;
    destructor Destroy;override;
    procedure Check(log: TAAWizardLog);override;
    procedure LoadControls;override;
    procedure LoadData;override;
    procedure RetrieveData;override;
    function GetNext: TAAQuestion;override;
    procedure GetLinks(links: TList);override;
    procedure ResetLinks;override;
    procedure UnloadControls;override;
  published
    property Prompt: string read FPrompt write FPrompt;
    property {<<Link>>}: TAAQuestion read F{<<Link>>} write F{<<Link>>};
  end;


procedure Register;

implementation

procedure Register;
begin
  RegisterNoIcon([{<<ClassName>>}]);
end;

{==============================================================================}
{ {<<MenuName>>} Question class implementation }

{ construct owned objects }
constructor {<<ClassName>>}.Create(aowner: TComponent);
begin
  inherited Create(aowner);
  { ! create owned objects here ! }
end;

{------------------------------------------------------------------------------}

{ destroy owned objects }
destructor {<<ClassName>>}.Destroy;
begin
  { ! free owned objects here ! }
  inherited Destroy;
end;

{------------------------------------------------------------------------------}

{ override to check whether question has valid settings; check for a Prompt and
  ensure the links are valid }
procedure {<<ClassName>>}.Check(log: TAAWizardLog);
begin

  inherited Check(log);
  if Prompt = '' then
    log.Add(Name + ' has no prompt', wlWarn);

  CheckLink('{<<Link>>}', {<<Link>>}, log);

end;

{------------------------------------------------------------------------------}

{ override to draw the controls that the question uses to show itself on the
  wizard form, using the Wizard's font and size guidelines }
procedure {<<ClassName>>}.LoadControls;
begin

  inherited LoadControls;

  { prompt label }
  FPromptLabel := TLabel.Create(DrawControl);
  with FPromptLabel do begin
    Font := Wizard.PromptFont;
    AutoSize := false;
    SetBounds(Wizard.PromptLeft, Wizard.PromptTop, Wizard.PromptWidth,
        Wizard.PromptHeight);
    Parent := DrawControl;
  end;

  { ! create any additional controls here; remember to call
      Wizard.SetFocusControl to set the active control ! }


end;

{------------------------------------------------------------------------------}

{ override to initialize the contents of the question's controls }
procedure {<<ClassName>>}.LoadData;
begin
  inherited LoadData;
  FPromptLabel.Caption := Prompt;
  { ! initialize any other controls here ! }
end;

{------------------------------------------------------------------------------}

{ update the question's properties with the values its controls display }
procedure {<<ClassName>>}.RetrieveData;
begin
  inherited RetrieveData;
  { ! update properties here ! }
end;

{------------------------------------------------------------------------------}

{ nil the references to the any link questions if it is being deleted }
procedure {<<ClassName>>}.Notification(comp: TComponent; op: TOperation);
begin
  inherited Notification(comp, op);
  if (comp is TAAQuestion) and (op = opRemove) then begin
    if comp = {<<Link>>} then F{<<Link>>} := nil;
  end;
end;


{------------------------------------------------------------------------------}

{ return the next question that the wizard should jump to after processing
  this question (this enables you to determine the next question depending
  on the question's run-time state) }
function {<<ClassName>>}.GetNext: TAAQuestion;
begin
  result := nil;
  { ! you MUST replace the above code to indicate the next question ! }
end;

{------------------------------------------------------------------------------}

{ Merlin calls this to determine what links are set in the question. }
procedure {<<ClassName>>}.GetLinks(links: TList);
begin
  links.Add({<<Link>>});
end;

{------------------------------------------------------------------------------}

{ Merlin calls this to make the question set all of its links to nil }
procedure {<<ClassName>>}.ResetLinks;
begin
  {<<Link>>} := nil;
end;

{------------------------------------------------------------------------------}

{ destroy any controls that were created in LoadControls }
procedure {<<ClassName>>}.UnloadControls;
begin
  inherited UnloadControls;
  FPromptLabel.Free;
  FPromptLabel := nil;
  { ! free and nil any controls that you created in LoadControls ! }
end;

{==============================================================================}

{ register the question class with the Merlin run time environment }
initialization

  AARegisterQuestionClass('{<<MenuName>>}', {<<ClassName>>});

end.
